==> comedi-0.4.2.tgz: comedi-0.4.2/demo/info.c <==
#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

void help(void)
{
	fprintf(stderr,"info <file>\n");
	exit(0);
}

char *flagstring[]={"rw","ro","rw,s","ro,s"};

char *tobinary(char *s,int bits,int n);


void main(int argc,char *argv[])
{
	int i,j,ret;
	int it;
	char s[20];
	comedi_info info;
	comedi_param param;
	
	if(argc!=2)help();

	it=open(argv[1],O_RDWR);
	if(!it){
		fprintf(stderr,"cannot open %s\n",argv[1]);
		exit(0);
	}

	comedi_getinfo(it,&info);
	
	printf("overall info:\n");
	printf("  minor: %d\n",info.minor);
	printf("  iobase: 0x%04x\n",info.iobase);
	printf("  iosize: 0x%04x\n",info.iosize);
	printf("  irq: %d\n",info.irq);
	printf("  number of channels: %d\n",info.chan);
	
	for(i=0;i<info.chan;i++){
		printf("channel %d:\n",i);
		j=0;
		for(;;){
			param.chan=i;
			param.pnum=j;
			ret=ioctl(it,COMEDI_GETNPARAM,&param);
			if(ret<0)break;
			
			printf("   %-4.4s ",flagstring[param.flags]);
			switch(param.pnum){
			case COMEDI_IO:
				switch(param.pval){
				case COMEDI_IO_INPUT:
					printf("input");
					break;
				case COMEDI_IO_OUTPUT:
					printf("output");
					break;
				case COMEDI_IO_BIDIR:
					printf("bidirectional");
					break;
				default:
					printf("input/output unknown");
					break;
				}
				break;
			case COMEDI_AD:
				switch(param.pval){
				case COMEDI_AD_ANALOG:
					printf("analog");
					break;
				case COMEDI_AD_DIGITAL:
					printf("digital");
					break;
				default:
					printf("analog/digital unknown");
					break;
				}
				break;
			case COMEDI_BITS:
				printf("number of bits=%d",param.pval);
				break;
			case COMEDI_MAXDATA:
				printf("max data=%d",param.pval);
				break;
			case COMEDI_RANGE:
				printf("range=[%d]",param.pval);
				break;
			case COMEDI_LASTDATA:
				printf("last data=%d",param.pval);
				break;
			case COMEDI_LASTSEC:
				printf("last sec=%d",param.pval);
				break;
			case COMEDI_LASTNSEC:
				printf("last nsec=%d",param.pval);
				break;
			case COMEDI_AREF:
				printf("analog reference: ");
				switch(param.pval){
				case COMEDI_AREF_GND:
					printf("ground");
					break;
				case COMEDI_AREF_COM:
					printf("floating common");
					break;
				case COMEDI_AREF_DIFF:
					printf("differential");
					break;
				case COMEDI_AREF_OTHER:
					printf("other");
					break;
				default:
					printf("unknown");
					break;
				}
				break;
			case COMEDI_DITHER:
				printf(param.pval?"dither enabled"
					:"dither disabled");
				break;
			case COMEDI_DEGLITCH:
				printf(param.pval?"deglitch enabled"
					:"deglitch disabled");
				break;
			case COMEDI_STROBE:
				printf(param.pval?"strobe enabled"
					:"strobe disabled");
				break;
			case COMEDI_IOBITGROUP:
				printf("# of bits grouped for I/O determination: %d",
					param.pval);
				break;
			case COMEDI_IOBITS:
				printf("I/O bitfield (1=output): 0b%s",
					tobinary(s,param.pval,16));
				break;
			case COMEDI_COUNT:
				printf("counter value: %d\n",param.pval);
				break;
			default:
				printf("unknown %d",param.pval);
			}
			printf("\n");
			j++;
		}
	}
}

char *tobinary(char *s,int bits,int n)
{
	int bit=1<<n;
	char *t=s;
	
	for(;bit;bit>>=1)
		*t++=(bits&bit)?'1':'0';
	*t=0;
	
	return s;
}

==> comedi-0.4.3.tgz: comedi-0.4.3/demo/info.c <==
#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

void help(void)
{
	fprintf(stderr,"info </dev/comediN>\n");
	exit(0);
}

char *flagstring[]={"rw","ro","rw,s","ro,s"};

char *tobinary(char *s,int bits,int n);


void main(int argc,char *argv[])
{
	int i,j,ret;
	int it;
	char s[20];
	comedi_info info;
	comedi_param param;
	
	if(argc!=2)help();

	it=open(argv[1],O_RDWR);
	if(!it){
		fprintf(stderr,"cannot open %s\n",argv[1]);
		exit(0);
	}

	comedi_getinfo(it,&info);
	
	printf("overall info:\n");
	printf("  minor: %d\n",info.minor);
	printf("  iobase: 0x%04x\n",info.iobase);
	printf("  iosize: 0x%04x\n",info.iosize);
	printf("  irq: %d\n",info.irq);
	printf("  number of channels: %d\n",info.chan);
	
	for(i=0;i<info.chan;i++){
		printf("channel %d:\n",i);
		j=0;
		for(;;){
			param.chan=i;
			param.pnum=j;
			ret=ioctl(it,COMEDI_GETNPARAM,&param);
			if(ret<0)break;
			
			printf("   %-4.4s ",flagstring[param.flags]);
			switch(param.pnum){
			case COMEDI_IO:
				switch(param.pval){
				case COMEDI_IO_INPUT:
					printf("input");
					break;
				case COMEDI_IO_OUTPUT:
					printf("output");
					break;
				case COMEDI_IO_BIDIR:
					printf("bidirectional");
					break;
				default:
					printf("input/output unknown");
					break;
				}
				break;
			case COMEDI_AD:
				switch(param.pval){
				case COMEDI_AD_ANALOG:
					printf("analog");
					break;
				case COMEDI_AD_DIGITAL:
					printf("digital");
					break;
				default:
					printf("analog/digital unknown");
					break;
				}
				break;
			case COMEDI_BITS:
				printf("number of bits=%d",param.pval);
				break;
			case COMEDI_MAXDATA:
				printf("max data=%d",param.pval);
				break;
			case COMEDI_RANGE:
				printf("range=[%d]",param.pval);
				break;
			case COMEDI_LASTDATA:
				printf("last data=%d",param.pval);
				break;
			case COMEDI_LASTSEC:
				printf("last sec=%d",param.pval);
				break;
			case COMEDI_LASTNSEC:
				printf("last nsec=%d",param.pval);
				break;
			case COMEDI_AREF:
				printf("analog reference: ");
				switch(param.pval){
				case COMEDI_AREF_GND:
					printf("ground");
					break;
				case COMEDI_AREF_COM:
					printf("floating common");
					break;
				case COMEDI_AREF_DIFF:
					printf("differential");
					break;
				case COMEDI_AREF_OTHER:
					printf("other");
					break;
				default:
					printf("unknown");
					break;
				}
				break;
			case COMEDI_DITHER:
				printf(param.pval?"dither enabled"
					:"dither disabled");
				break;
			case COMEDI_DEGLITCH:
				printf(param.pval?"deglitch enabled"
					:"deglitch disabled");
				break;
			case COMEDI_STROBE:
				printf(param.pval?"strobe enabled"
					:"strobe disabled");
				break;
			case COMEDI_IOBITGROUP:
				printf("# of bits grouped for I/O determination: %d",
					param.pval);
				break;
			case COMEDI_IOBITS:
				printf("I/O bitfield (1=output): 0b%s",
					tobinary(s,param.pval,16));
				break;
			case COMEDI_COUNT:
				printf("counter value: %d\n",param.pval);
				break;
			default:
				printf("unknown %d",param.pval);
			}
			printf("\n");
			j++;
		}
	}
}

char *tobinary(char *s,int bits,int n)
{
	int bit=1<<n;
	char *t=s;
	
	for(;bit;bit>>=1)
		*t++=(bits&bit)?'1':'0';
	*t=0;
	
	return s;
}
